/**
 * main.js
 *
 * Bootstraps Vuetify and other plugins then mounts the App`
 */

// Plugins
import { registerPlugins } from '@/plugins'
import '@/styles/index.scss'

import Viewer from 'v-viewer'
import 'viewerjs/dist/viewer.css'

import App from './App.vue'
import { createApp } from 'vue'

import { createPinia } from 'pinia'

import piniaPluginPersistedstate from 'pinia-plugin-persistedstate' // pinia 持久化

import router from './router'

import './permission'

const pinia = createPinia()

pinia.use(piniaPluginPersistedstate)

const app = createApp(App)

app.use(pinia)
app.use(router)
app.use(Viewer, {
  Options: {
    'inline': true,
    'title': false,
    'button': true, // 右上角按钮
    'navbar': true, // 底部缩略图
    'zoomable': true, // 是否可以缩放
    'rotatable': true, // 是否可以旋转
    'scalable': true, // 是否可以翻转
    'fullscreen': true, // 播放时是否支持全屏
    'url': 'data-source',
    'toolbar': true // 底部工具栏
  }
})

registerPlugins(app)

app.mount('#app')
